@ECHO OFF
SETLOCAL ENABLEDELAYEDEXPANSION
SETLOCAL ENABLEEXTENSIONS
SET neededfiles=gsar.exe dsfo.exe dsfi.exe fsz.exe bpatcher.exe
FOR %%A IN (%neededfiles%) DO IF NOT EXIST %%A ECHO Missing file: %%A& GOTO :ERROR1
GOTO :HDDIMG

:Syntax
ECHO.
ECHO %~nx0 batch file to create a harddisk image - 0.8 ALPHA 19th Feb. 2011
ECHO by jaclaz (as modified by oriensol), this file is licensed under jaclaz's "CAREWARE" license:
ECHO http://jaclaz.altervista.org/Projects/careware.html
ECHO.
ECHO targetfile diskimagesize [round-to-cylinder=/R] : Creates 255x63 geometry disk image, given the disk image size
ECHO.
ECHO Notes:
ECHO       This script is based on mbrbatch.cmd and mkimg.cmd but makes simplifying assumptions
ECHO       whereas the original script is very comprehensive.
ECHO       Adapted from jaclaz's scripts by oriensol
ECHO       Obtain neededfiles from jaclaz's tool 
ECHO       Visit the link http://www.boot-land.net/forums/index.php?showtopic=9033 for details
ECHO       Visit the link http://www.boot-land.net/forums/?showtopic=5000 for AMD64 bpatcher.exe
ECHO       Version History
ECHo       0.2 Added AMD64 support and .pln file in destination directory for 255/63 geometry
ECHO       0.3 Added support for , instead of . in European windows and removed assumption of English language
ECHO       0.4a Fixed AMD64 issue and removed use of echoo.com, using bpatcher instead in all cases
ECHO       0.4b Added support for blanks in file path and name
ECHO       0.4c Added check for dmadmin.exe in current directory and error if not supplied
ECHO       0.4d If size given is less than 16 MB, instead of error message the smallest possible image is created
ECHO       0.5 Fixed issue when comma separator as defined in the OS is a special character
ECHO       0.6 Fixed issue when the image size in bytes exceeds the 32 bit numeric dos limit
ECHO       0.7 UNofficial ALPHA - quickly added a Disk Signature generating routine - by jaclaz
ECHO       0.8 UNofficial ALPHA - Corrected a CRITICAL ERROR that created WRONG ECyl on images ^> 2Gb - by jaclaz
ECHO.
GOTO :EOF

:HDDIMG
SET Targetfile=%1
SET GivenFilesize=%2
SET Round2Cyl=%3
SET ExtraParam=%4
IF NOT DEFINED Targetfile GOTO :HDDIMGHELP
IF NOT DEFINED GivenFilesize GOTO :HDDIMGHELP
IF DEFINED ExtraParam GOTO :HDDIMGHELP
IF DEFINED Round2Cyl IF /I NOT %Round2Cyl%.==/R. GOTO :HDDIMGHELP
SET Filesize=%GivenFilesize%
IF DEFINED Filesize (CALL :check_filesize) 
:: :check_filesize changes %Filesize%
IF NOT DEFINED Filesize GOTO :HDDIMGHELP
CALL :Do_Divide %Filesize% 512
SET TotSectors=%Result%
IF NOT DEFINED TotSectors (CALL :SET-TO-MINIMUM)
::If image is smaller than 16,450,560 bytes, i.e. of 32,130 sectors, it cannot be used with 255/63
::Round it up to the smallest possible size of 32130 sectors
CALL :PURESTR_COMPARE %TotSectors% "32130"
IF %COMPRESULT% lss 0 (CALL :SET-TO-MINIMUM)
IF /I %Round2Cyl%.==/R. (CALL :DO-ROUNDING)
CALL :FREEBYTES %~d1
IF NOT DEFINED FREEBYTENUM GOTO :WRONG-DRIVE
CALL :PURESTR_COMPARE %FREEBYTENUM% "1"
IF %COMPRESULT% lss 0 GOTO :WRONG-DRIVE
CALL :PURESTR_COMPARE %FREEBYTENUM% %Filesize%
IF %COMPRESULT% leq 0 GOTO :NO-SPACE

:PREPARE
SET Targetfile=%Targetfile:"=%
SET /A MAXCyl=(%TotSectors%/63/255)
SET /A ECyl=%MAXCyl%-1
SET /A SectorsLBA=%TotSectors%-63
SET gsarstring=gsar -b -s:x33:xC0:x8E:xD0:xBC:x00:x7C:xFB:x50
SET Sysfile=%~d0dmadmin.exe
IF EXIST dmadmin.exe (GOTO :SYSFILE)
ECHO.
ECHO dmadmin.exe not found in current directory, trying to copy from %SystemRoot%\System32\dmadmin.exe
REM SET Sysfile=%SystemRoot%\System32\spcmdcon.sys
REM SET Sysfile=%SystemRoot%\ServicePackFiles\I386\setupdd.sys
IF EXIST %SystemRoot%\System32\dmadmin.exe COPY /Y %SystemRoot%\System32\dmadmin.exe .
IF EXIST dmadmin.exe (GOTO :SYSFILE)
ECHO. 
ECHO dmadmin.exe not found in "%~dp0", please copy the file
GOTO :NO-SYSFILE
:SYSFILE
FOR /F "tokens=3 delims=:" %%A IN ('%gsarstring% %Sysfile%^|FIND "%Sysfile%"^| FIND /V "match found"') DO SET /A Offset=%%A
SET /A Offset=%Offset%
Set /A Length=512
ECHO Creating an MBR from "%~dp0dmadmin.exe" with dsfo.exe
IF EXIST MBRFILE.$$$ del MBRFILE.$$$
dsfo %Sysfile% %Offset% %Length% MBRFILE.$$$
SET Powers=32768 16384 8192 4096 2048 1024 512 256 128 64 32 16 8 4 2 1
CALL :DEC2BIN %ECyl%
SET ECyl=%BINNUM:~-10,10%
SET Esec=63
CALL :DEC2BIN %ESec%
SET ESec=%BINNUM:~-6,6%
SET ESec=%ECyl:~0,2%%ESec%
SET ECyl=%ECyl:~-8,8%
SET Powers=128 64 32 16 8 4 2 1
CALL :BIN2DEC !ESec! 8
SET ESec=!DECnum!
CALL :BIN2DEC !ECyl! 8
SET ECyl=!DECnum!
CALL :DEC2hex !ESec! 2
SET ESec=!HEXnum!
CALL :DEC2hex !ECyl! 2
SET ECyl=!HEXnum!
CALL :DEC2hex !SectorsLBA! 8
SET SectorsLBA=!HEXnum!
SET DataString=$80$01$01$00$07$FE$3F$%ECyl%$3F$00$00$00$%SectorsLBA:~0,2%$%SectorsLBA:~2,2%$%SectorsLBA:~4,2%$%SectorsLBA:~6,2%
call :PARTENTRY PARTENT.$$$
dsfi MBRFILE.$$$ 446 16 PARTENT.$$$ > nul
call :DISKSIG DISKSIG.$$$
dsfi MBRFILE.$$$ 440 4 DISKSIG.$$$ > nul

:DO-IT-THERE
%~d1
cd %~p1
"%~dp0fsz.exe" HDDIMAGE.$$$ %Filesize% > nul
"%~dp0dsfi.exe" HDDIMAGE.$$$ 0 512 "%~dp0MBRFILE.$$$" > nul
CALL :MAKEPLN "%Targetfile%" HDIMGPLN.$$$
IF EXIST "%~nx1" ECHO Deleting %1
MOVE /Y HDDIMAGE.$$$ "%~nx1"
MOVE /Y HDIMGPLN.$$$ "%~n1.PLN"
ECHO.
ECHO Created hard-disk image %1 (Size=%Filesize%, Sectors=%TotSectors%, Cylinders=%MAXCyl%)

:CLEANUP
%~d0
cd %~p0
del /F PARTENT.$$$ MBRFILE.$$$ 
GOTO :EOF

:DO-ROUNDING
:: Round to the next higher multiple of 16065, i.e., 255*63
SET /A TotSectors="((%TotSectors%-1)+16065-((%TotSectors%-1) %% 16065))"
CALL :Do_Multiply %TotSectors% 512
SET Filesize=%Result%
GOTO :EOF

:SET-TO-MINIMUM
:: Round to the lowest possible size with 255/63 geometry
SET /A TotSectors=32130
CALL :Do_Multiply %TotSectors% 512
SET Filesize=%Result%
GOTO :EOF

:PARTENTRY
echo 0123456789ABCD> %1
bpatcher.exe %1 00 80 > nul
bpatcher.exe %1 01 01 > nul
bpatcher.exe %1 02 01 > nul
bpatcher.exe %1 03 00 > nul
bpatcher.exe %1 04 07 > nul
bpatcher.exe %1 05 FE > nul
bpatcher.exe %1 06 %ESec% > nul
bpatcher.exe %1 07 %ECyl% > nul
bpatcher.exe %1 08 3F > nul
bpatcher.exe %1 09 00 > nul
bpatcher.exe %1 0A 00 > nul
bpatcher.exe %1 0B 00 > nul
bpatcher.exe %1 0C %SectorsLBA:~0,2% > nul
bpatcher.exe %1 0D %SectorsLBA:~2,2% > nul
bpatcher.exe %1 0E %SectorsLBA:~4,2% > nul
bpatcher.exe %1 0F %SectorsLBA:~6,2% > nul
GOTO :EOF

:MAKEPLN
SET Targetpln=%2
ECHO %Targetpln% > nul
(
ECHO DRIVETYPE ide
ECHO CYLINDERS %MAXCyl%
ECHO HEADS 255
ECHO SECTORS 63
ECHO ACCESS "%~nx1" 0 %TotSectors%
)>%Targetpln%

GOTO :EOF

:error
ECHO %~nx0: An error has occurred
GOTO :EOF

:error1
ECHO.
ECHO %~nx0: Please add the missing file in the same directory where %~nx0 is
GOTO :EOF

:WRONG-DRIVE
ECHO.
ECHO %~nx0: Parameters supplied - %1 %GivenFilesize% %Round2Cyl%
ECHO %~nx0: Error - Partition/Drive %DRIVELETTER% does not exist/is not ready/is readonly/doesn't have media
GOTO :EOF

:NO-SPACE
ECHO.
ECHO %~nx0: Parameters supplied - %1 %GivenFilesize% %Round2Cyl%
ECHO %~nx0: Error - Not enough freespace on drive %DRIVELETTER% - needed %Filesize% bytes; available %FREEBYTENUM% bytes
GOTO :EOF

:TOO-SMALL
ECHO.
ECHO %~nx0: Error - Disk Image Size supplied is "%GivenFilesize%" - size cannot be less than 16 MB for 255/63 geometry
GOTO :HDDIMGHELP
GOTO :EOF

:NO-SYSFILE
ECHO.
ECHO %~nx0: Error - System file to base the MBR on (dmadmin.exe) not found - please copy it to the current directory
GOTO :HDDIMGHELP
GOTO :EOF

:NON-NUMERIC
ECHO.
ECHO %~nx0: Error - Disk Image Size supplied is "%GivenFilesize%" - size should be an integer (bytes - add a suffix K, M or G for Kilo, Mega or Giga)
GOTO :EOF

:check_filesize
SET Filesize=%Filesize:,=%
SET Filesize=%Filesize:.=%
FOR %%A in ( K M G) do (
IF /I %Filesize:~-1,1%.==%%A. (
SET Suffix=%%A
SET Filesize=%Filesize:~0,-1%
)
)

SET is_number=%Filesize%
FOR %%A in (0 1 2 3 4 5 6 7 8 9) DO (
SET is_number=!is_number:%%A=!
IF NOT DEFINED is_number GOTO :is_number 
)
:is_number
IF DEFINED is_number SET Filesize= & GOTO :NON-NUMERIC 

Set UnitM=1
FOR %%A IN (1024.K 1048576.M 1073741824.G) DO (
IF  /I .%Suffix%==%%~xA SET UnitM=%%~nA
)

CALL :Do_Multiply %Filesize% %UnitM%
SET Filesize=%Result%
GOTO :EOF

:Do_divide
Set Number=%1
Set Divider=%2
Set Separator=%1%2
For %%A in (D_Length N_Length %M_s% %N_s% %R_s% Result ) DO SET %%A=

::Find Separator
FOR %%A IN (0 1 2 3 4 5 6 7 8 9) DO IF DEFINED Separator Set Separator=!Separator:%%A=!
IF DEFINED Separator SET Separator=%Separator:~0,1%

::Remove dots or commas
IF DEFINED Separator Set Number=!Number:%Separator%=!
IF DEFINED Separator Set Divider=!Divider:%Separator%=!

FOR %%A IN (1 2 3 4 5 6 7 8 9 10 11 12 13 14 15) DO (
IF NOT DEFINED N_Length IF "!Number:~0,%%A!"=="!Number:~0!" SET N_Length=%%A
IF NOT DEFINED D_Length IF "!Divider:~0,%%A!"=="!Divider:~0!" SET D_Length=%%A
)

IF %D_Length% gtr 9 SET Result=0 &GOTO :EOF
SET /A Counter=0
SET divideArg=
CALL :divideloop
IF DEFINED Separator SET Digits=3&CALL :Putdots
GOTO :EOF

:divideloop
SET divideARG=%divideArg%!Number:~%Counter%,1!
SET /A Counter=%Counter%+1
SET /A Quotient=%divideArg%/%divider%
SET Result=%Result%%quotient%
IF %Result:~0,1%==0 SET Result=%Result:~1%
SET /A Rest=%divideArg% %% %divider%
IF %Rest%==0 SET Rest=
SET divideARG=%Rest%
IF %Counter% lss %N_length% GOTO :divideloop
GOTO :EOF

:Do_Multiply
Set Number=%1
Set Multiplier=%2
Set Separator=%1%2
For %%A in (MLength NLength %M_s% %N_s% %R_s% Result ) DO SET %%A=

::Find Separator
FOR %%A IN (0 1 2 3 4 5 6 7 8 9) DO IF DEFINED Separator Set Separator=!Separator:%%A=!
IF DEFINED Separator SET Separator=%Separator:~0,1%

::Remove dots or commas
IF DEFINED Separator Set Number=!Number:%Separator%=!
IF DEFINED Separator Set Multiplier=!Multiplier:%Separator%=!

FOR %%A IN (1 2 3 4 5 6 7 8 9 10 11 12 13 14 15) DO (
IF NOT DEFINED NLength IF "!Number:~0,%%A!"=="!Number:~0!" SET NLength=%%A
IF NOT DEFINED MLength IF "!Multiplier:~0,%%A!"=="!Multiplier:~0!" SET MLength=%%A
)

SET /A RLength=%NLength%+%MLength%
IF %Rlength% gtr 15 SET Result=0 &GOTO :EOF
Set Zeroes=000000000000000
SET N_s=N1
SET M_s=M1
SET R_s=R1
FOR %%A IN (1 2 3 4 5 6 7 8 9 10 11 12 13 14 15) DO (
IF %%A lss %NLength% SET N_s=!N_s! N1.!Zeroes:~0,%%A!
IF %%A lss %MLength% SET M_s=!M_s! M1.!Zeroes:~0,%%A!
IF %%A lss %RLength% SET R_s=!R_s! R1.!Zeroes:~0,%%A!
)


::Reverse numbers
SET Number=%Number:~14,1%%Number:~13,1%%Number:~12,1%%Number:~11,1%%Number:~10,1%%Number:~9,1%%Number:~8,1%%Number:~7,1%%Number:~6,1%%Number:~5,1%%Number:~4,1%%Number:~3,1%%Number:~2,1%%Number:~1,1%%Number:~0,1%
SET Multiplier=%Multiplier:~14,1%%Multiplier:~13,1%%Multiplier:~12,1%%Multiplier:~11,1%%Multiplier:~10,1%%Multiplier:~9,1%%Multiplier:~8,1%%Multiplier:~7,1%%Multiplier:~6,1%%Multiplier:~5,1%%Multiplier:~4,1%%Multiplier:~3,1%%Multiplier:~2,1%%Multiplier:~1,1%%Multiplier:~0,1%
Set Counter=0
FOR %%A IN (%N_s%) DO CALL :Assign_digits %%A Number
Set Counter=0
FOR %%A IN (%M_s%) DO CALL :Assign_digits %%A Multiplier


For %%A in (%M_s%) DO (
For %%B IN (%N_s%) DO (
IF DEFINED %%B CALL :Multiply %%A %%B
)
)
For %%A in (%R_s%) DO CALL :ReADD %%A
For %%A in (%R_s%) DO SET Result=!Result!!%%A!

::Reverse numbers
SET Result=%Result:~14,1%%Result:~13,1%%Result:~12,1%%Result:~11,1%%Result:~10,1%%Result:~9,1%%Result:~8,1%%Result:~7,1%%Result:~6,1%%Result:~5,1%%Result:~4,1%%Result:~3,1%%Result:~2,1%%Result:~1,1%%Result:~0,1%
IF %Result:~0,1%==0 SET Result=%Result:~1%
IF DEFINED Separator SET Digits=3&CALL :Putdots
GOTO :EOF

:Multiply
SET CurrR=R1%~x1%~x2
SET CurrR=%CurrR:0.=0%
SET CurrN=%1
SET CurrM=%2
SET /A %CurrR%=!%CurrR%!+!%CurrN%!*!%CurrM%!
GOTO :EOF

:ReADD
SET CurrR=%1
IF %CurrR%==R1 (SET CurrR=R1&SET NextR=R1.0) ELSE (SET NextR=%10)
IF NOT DEFINED %NextR% SET %NextR%=0
IF !%CurrR%! gtr 99 (
SET /A %NextR%=!%CurrR%:~-3,2!+!%NextR%!
SET /A %CurrR%=!%CurrR%:~-1,1!
)
IF !%CurrR%! gtr 9 (
SET /A %NextR%=!%CurrR%:~-2,1!+!%NextR%!
SET /A %CurrR%=!%CurrR%:~-1,1!
)
GOTO :EOF

:Putdots
Set Result=!Result:~0,-%Digits%!#!Result:~-%Digits%,%Digits%! 
Set /A Digits=%Digits%+5
IF NOT %Result:~0,1%==# GOTO :Putdots
Set Result=%Result:~1%
Set Result=!Result:#=%Separator%!
GOTO :EOF

:Assign_digits
SET %1=!%2:~%Counter%,1!
Set /A Counter=%Counter%+1
GOTO :EOF

:FREEBYTES
SET FREEBYTETEXT=
FOR /F  "tokens=3 delims= " %%A in ('dir %1 ^| FIND /I " "') DO (
SET FREEBYTETEXT=%%A
)
SET FREEBYTENUM=
IF NOT DEFINED FREEBYTETEXT GOTO :EOF
SET dchar=
SET pdchar=%FREEBYTETEXT:~-4,1%
if %pdchar%. lss 0. set dchar=%pdchar%
if %pdchar%. gtr 9. set dchar=%pdchar%
if "%dchar%." == "." (SET FREEBYTENUM=%FREEBYTETEXT% & GOTO :EOF)
for /F "tokens=1-10 delims=%dchar%" %%A in ("%FREEBYTETEXT%") do (
SET FREEBYTENUM=%%A%%B%%C%%D%%E%%F%%G%%H%%I%%J
)
GOTO :EOF

:DEC2hex
SET DECnum=%1
SET Numdig=%2
SET HEXnum=
SET Powers=268435456 16777216 1048576 65536 4096 256 16 1
::=======================================================
::| WARNING! Limit is 2147483647 i.e. 7FFFFFF  WARNING! |
::=======================================================
SET /A Limit=%DECnum%/16
IF %Limit% LSS 0 ECHO Out of Range &GOTO :EOF
SET /A Val268435456=%DECnum% / 268435456
SET /A Mod268435456=%DECnum% %% 268435456
FOR %%A in (%Powers%) DO CALL:HEXcalc %%A
FOR %%A in (%Powers%) DO CALL:HEXchar %%A
FOR %%A in (%Powers%) DO SET Hexnum=!Hexnum!!Val%%A!

SET /A Length=8
SET HexnumF=%Hexnum%
CALL :RemoveLead
GOTO :EOF

:RemoveLead
Set/A Length=%Length%-2
IF %HexnumF:~0,2%==00 set HEXnumF=!HexnumF:~-%Length%!&GOTO :RemoveLead
SET HexnumF=!Hexnum:~-%NumDig%!
SET Hexnum=%HexnumF:~6,2%%HexnumF:~4,2%%HexnumF:~2,2%%HexnumF:~0,2%
GOTO :EOF

:HEXcalc
IF %1==1 GOTO :EOF
SET /A Div=%1 /16
SET /A Val%Div%=!Mod%1! / %Div%
SET /A Mod%Div%=!Mod%1! %% %Div%
GOTO :EOF

:HEXchar
IF !Val%1!==10 SET Val%1=A
IF !Val%1!==11 SET Val%1=B
IF !Val%1!==12 SET Val%1=C
IF !Val%1!==13 SET Val%1=D
IF !Val%1!==14 SET Val%1=E
IF !Val%1!==15 SET Val%1=F
GOTO :EOF

:DEC2BIN
SET BINnum=
SET DECnum=%1
SET /A Val32768=%DECnum% / 32768
SET /A Mod32768=%DECnum% %% 32768
FOR %%A in (%Powers%) DO CALL:BINcalc %%A
FOR %%A in (%Powers%) DO SET BINnum=!BINnum!!Val%%A!
GOTO :EOF

:BINcalc
IF %1==1 GOTO :EOF
SET /A Div=%1 /2
SET /A Val%Div%=!Mod%1! / %Div%
SET /A Mod%Div%=!Mod%1! %% %Div%
GOTO :EOF

:BIN2DEC
SET DECnum=
SET BINnum=%1
SET BINLength=%2
Set Counter=0
FOR %%A IN (%Powers%) DO (
CALL :DECcalc %%A
SET /A Counter=!Counter!+1
)
FOR %%A IN (%Powers%) DO SET /A DECnum=!DECnum!+!Digit%%A!*%%A
GOTO :EOF

:DECcalc
SET digit%1=!BINNum:~%Counter%,1!
IF %Counter%==%BINLength% GOTO :EOF
GOTO :EOF

:PURESTR_COMPARE
CALL :GET_LENGTH %1
SET /A FirstLen = %length%
CALL :GET_LENGTH %2
SET /A SecondLen = %length%
if %FirstLen% lss %SecondLen% SET /A COMPRESULT = -1 & GOTO :EOF
if %FirstLen% gtr %SecondLen% SET /A COMPRESULT = 1 & GOTO :EOF
if "X%1" lss "X%2" SET /A COMPRESULT = -1 & GOTO :EOF
if "X%1" gtr "X%2" SET /A COMPRESULT = 1 & GOTO :EOF
SET /A COMPRESULT = 0
GOTO :EOF

:: Set the variable %length% to Length of string
:GET_LENGTH
set #=%1
set length=0
:loop
if defined # (set #=%#:~1%&set /A length += 1&goto loop)
GOTO :EOF

:DISKSIG
echo 01> %1
CALL :RAND Sig00
CALL :RAND Sig01
CALL :RAND Sig02
CALL :RAND Sig03
ECHO Disk Signature is: %Sig00%%Sig01%%Sig02%%Sig03%
bpatcher.exe %1 00 %Sig00% > nul
bpatcher.exe %1 01 %Sig01% > nul
bpatcher.exe %1 02 %Sig02% > nul
bpatcher.exe %1 03 %Sig03% > nul
GOTO :EOF

:RAND
SET %1=%Random%
IF !%1! GTR 255 GOTO :RAND
CALL :DEC2hex !%1! 2
SET %1=%HEXnum%
GOTO :EOF

:HDDIMGHELP
ECHO.
ECHO Usage: %~nx0 targetfile diskimagesize [round-to-cylinder=/R] 

ECHO.
ECHO    targetfile is the path of the Disk Image File to be created
ECHO. 
ECHO    diskimagesize is the image size in bytes - add a suffix K, M or G for Kilo, Mega or Giga
ECHO. 
ECHO    Optionally, specify '/R' to round the disk image size to cylinder boundary
ECHO. 
ECHO 1. A copy of the MBR is embedded inside a few system files:
ECHO   - %%SystemRoot%%\System32\dmadmin.exe
ECHO   - %%SystemRoot%%\System32\spcmdcon.sys
ECHO   - %%SystemRoot%%\ServicePackFiles\I386\setupdd.sys
ECHO   %~nx0 uses dmadmin.exe by default 
ECHO.
ECHO   If you are using a "lited" 2K/XP where this file has been removed
ECHO   edit the batch accordingly, if you use the batch on just one system
ECHO   you may also set a fixed offset and avoid the need for gsar.exe
ECHO.
ECHO   If your OS doesn't have dmadmin.exe, find and copy it to the current directory
ECHO.2.
ECHO   The disk image is created with 255/63 geometry
ECHO   Minimum disk image size is 16 MB (for 255/63 geometry)
ECHO   If the size supplied is less than 32130 sectors, an image of size 32130 sectors will be created
ECHO   The largest possible partition is created, if size is not a multiple of 512
ECHO   A single unformatted NTFS partition is created
ECHO   Please format the partition later on to your liking
ECHO   You may also create multiple partitions later on, if needed
ECHO   Use the optional round-cylinder option (/R) to ensure image ends at cylinder boundary
ECHo   Using /R will prevent the grub4dos warning while mapping the drive
ECHO   Remember to use something like:
ECHO       vdk open * imagename.pln [/RW] /p:1 [/l:z:]
ECHO     each time you use the image with vdk or better still, do NOT use the /p switch at all
ECHo   When the round-cylinder option is used, the size is 'increased', if needed
ECHO.3.
ECHO   You can mount the image using vdk
ECHo   Use the .pln file in the target directory to open with 255/63 geometry using vdk
ECHo   The default geometry used by vdk is 64/32
ECHO   vdk available from http://chitchat.at.infoseek.co.jp/vmware/vdk.html
ECHO   You can also mount the image using ImDisk
ECHO.4.
ECHO   EXAMPLES:
ECHO     %~nx0 "X:\my folder\my disk.img" 20M
ECHO     %~nx0 my_disk2.img 1G /R
GOTO :EOF